@@ -428,8 +428,8 @@ AppDetailParticipants.prototype = {
                 printString += (this.idUserArr[i].display_name || this.idUserArr[i].mail) + ( i+1 == this.idUserArr.length ? "" : ", ");
             }
 		}
-		aPrintDetailApp.push(Print.createEmpty());
-		aPrintDetailApp.push(Print.createContent(_("Participants:"), printString));
+		aPrintDetailApp[9] = Print.createEmpty();
+		aPrintDetailApp[10] = Print.createContent(_("Participants:"), printString);
 
 		this.gridData.sort(function(a,b){
 			if (a[2] && b[2]) {
@@ -505,8 +505,8 @@ AppDetailParticipants.prototype = {
 					}
 				});
 				
-				aPrintDetailApp.push(Print.createEmpty());
-				aPrintDetailApp.push(Print.createContent("", arg[gr].display_name + ":"));
+				aPrintDetailApp[11] = Print.createEmpty();
+				aPrintDetailApp[12] = Print.createContent("", arg[gr].display_name + ":");
 				var printString = "";
 				for (var z=0; z<tmp_members.length;z++){
 					if (tmp_members[z]) {
@@ -515,7 +515,7 @@ AppDetailParticipants.prototype = {
 						printString += (tmp_members[z][2]) + ( z+1 == tmp_members.length ? "" : ", ");
 					}
 				}
-				aPrintDetailApp.push(Print.createContent("", printString));
+				aPrintDetailApp[13] = Print.createContent("", printString);
 			}
 		});
 		setTimeout(
@@ -548,8 +548,8 @@ AppDetailParticipants.prototype = {
 		}
 	    
 	    if (this.idResourceArr.length >= 0) {
-	        aPrintDetailApp.push(Print.createEmpty());
-	        aPrintDetailApp.push(Print.createContent(_("Resources:"), printString));
+	        aPrintDetailApp[14] = Print.createEmpty();
+	        aPrintDetailApp[15] = Print.createContent(_("Resources:"), printString);
 	    }
 	    
 		var Self = this;
