@@ -230,7 +230,9 @@ register("OX_Configuration_Loaded", function () {
 	    		delete(nData.password);
 	    	}
 	    	
-	    	if (nData.transport_credentials === false) {
+	    	if (nData.transport_credentials == true) {
+	    		nData.transport_auth = "custom";
+	    	} else if (nData.transport_credentials === false) {
 	    	    nData.transport_login = null;
 	    		nData.transport_password = null;
 	    	} else if (nData.transport_credentials !== true) {
@@ -636,6 +638,10 @@ register("OX_Configuration_Loaded", function () {
 	    	data.transport_protocol = "smtp";
 	    	data.tree = false;
 	    	
+	    	if (data.transport_credentials == true) {
+	    		data.transport_auth = "custom";
+	    	}
+
 	    	// validate account data
 	    	ox.api.account.validate(
 	    	    data,
