@@ -253,9 +253,12 @@ function cms_enter() {
 	cms_signatures = new Array();
 	// prevent JS error when signature isn't an array, try to reconvert it
     if (ox.api.config.contains("gui.mail.signatures")) {
-        cms_signatures = ox.api.config.get("gui.mail.signatures");
-        if (jQuery.isArray(cms_signatures) === false) {
-            cms_signatures = ObjectToArray(cms_signatures);
+        var o = ox.api.config.get("gui.mail.signatures");
+        cms_signatures = [];
+        for (var i in o) {
+            if (o.hasOwnProperty(i) && o[i] && typeof o[i] === "object") {
+                cms_signatures.push(o[i]);
+            }
         }
     }
 	cms_fillSignature();	
