@@ -1447,46 +1447,52 @@ function writeNewContact()
 	}
 }
 
-function finalUpdateObject() {
+function finalFunction(myObject) {
+    
+    function closeWindow() {
+        setTimeout(function() {
+            setBeforeUnload(false);
+            ctrl.close(true);
+        }, 50);
+    }
+    
+    if ("new_contains_image1" in myNewContactFunctions) {
+        contact_object.contains_image1 = myNewContactFunctions.new_contains_image1;
+    }
+    
+    if (tmp_attachmentDialog.attach_changed()) {
+        contact_object.number_of_attachments = tmp_attachmentDialog.file_storage.ids.length;
+        corewindow.triggerEvent("OX_Quota_Update");
+    }
+    
     // update cache in corewindow
     if (modulPopup === "new" || modulPopup === "duplicate") {
-        corewindow.OXContactMapping.createObject(contact_object);
-        return true;
+        setBeforeUnload(false);
+        corewindow.OXContactMapping.createObject(corewindow.clone(contact_object, window));
+        corewindow.closeContactPopUp(window, clickedItemForSave);
+        closeWindow();
+        
     } else if (modulPopup === "edit") {
+         setBeforeUnload(false);
          corewindow.OXCache.newRequest(null, "contacts", { columns: null,
              objects: [corewindow.OXContactMapping.createKeyFromObject({
                  module: "contacts", folder_id: clickedItemForSave,
                  id: contactDetailId
              })] }, null, emptyFunction, true);
-         if (activefolderLocal !== clickedItemForSave) {
+         if (activefolderLocal != clickedItemForSave) {
              corewindow.OXContactMapping.deleteObjectsInternal(
                  [corewindow.OXContactMapping.createKeyFromObject({
                      module: "contacts", folder_id: activefolderLocal,
                      id: contactDetailId
                  })]);
          }
-         return true;
+         corewindow.closeContactPopUp(window, clickedItemForSave);
+         closeWindow();
     }
 }
 
-function finalFunction(myObject) {
-    if ("new_contains_image1" in myNewContactFunctions) {
-        contact_object.contains_image1 = myNewContactFunctions.new_contains_image1;
-    }
-    if (tmp_attachmentDialog.attach_changed()) {
-        contact_object.number_of_attachments = tmp_attachmentDialog.file_storage.ids.length;
-        corewindow.triggerEvent("OX_Quota_Update");
-    }
-    // update object
-    if (finalUpdateObject()) {
-        setBeforeUnload(false);
-        corewindow.closeContactPopUp(window, clickedItemForSave);
-    }
-	setModalBusy();
-}
-
 /********************************** Tabs *****************************************************************/
-register("OX_Contact_New_Switch",function(param) { menuswitchContactNew(param) });
+register("OX_Contact_New_Switch",function(param) { menuswitchContactNew(param); });
 /**
  * global vars for new Contact
  */
