@@ -444,7 +444,7 @@ function drawMessage(message, folder) {
 	if(message["bcc"])  
 		detailmessage["bcc"]=refToMain.getAdressString(message["bcc"], false);
 	detailmessage["date"]=message["sent_date"];
-	detailmessage["subject"]=message["subject"];
+	detailmessage["subject"]=message["subject"] || "";
 	detailmessage["priority"]=message["priority"];
 	detailmessage["color-label"]=message["color_label"];
 	
