@@ -580,7 +580,7 @@ var setMailHeaderLabel;
         if (omsg.cc)  tmsg["cc"] = getAdressString(omsg.cc, false);
         if (omsg.bcc) tmsg["bcc"] = getAdressString(omsg.bcc, false);
         tmsg["date"] = omsg.sent_date;
-        tmsg["subject"] = omsg.subject;
+        tmsg["subject"] = omsg.subject || "";
         tmsg["priority"] = omsg.priority;
         tmsg["color-label"] = omsg.color_label;
         mail_printDetailMail(tmsg, closer); // closer is passed by ox.api
@@ -2217,7 +2217,7 @@ function sendMailToRecipientMail(recipient) {
 }
 
 function mail_quoteHTMLTags(val) {
-    return val || val.replace(/</gi,"&lt;").replace(/"/gi,"&quot;");
+    return (val || "").replace(/</gi,"&lt;").replace(/"/gi,"&quot;");
 }
 
 function mail_printDetailMail(messageobject, closer) {
