@@ -842,7 +842,8 @@ initMessageHeader = function () {
         var a = 0;
         for (; a < configGetKey("gui.mail.signatures").length; a++) {
             var signatures = configGetKey("gui.mail.signatures")[a];
-            var sig_name = signatures.signature_name.length === 0 ?
+            if (!signatures || typeof signatures !== "object") continue;
+            var sig_name = !signatures.signature_name ?
                 _("Unnamed signature") :
                 noI18n(signatures.signature_name);
             signature.addElement(sig_name, signatures);
@@ -1370,6 +1371,7 @@ setMailFields = function (mailobject) {
             oMailFunctionsNew.addAttachment({
                 id: nobj.id || "message/rfc822",
                 filename: textAttachment,
+                disp: "attachment",
                 size: null,
                 content_type: "message/rfc822",
                 msgref: nobj.msgref || null,
@@ -1658,7 +1660,7 @@ MailFunctions.prototype = {
 
     autosaveMessage: function () {
         var self = this;
-        if (!ums) {
+        if (!ums || self.savePending) {
             return; // nothing changed, so no need to save anything
         }
         this.getMailValues();
@@ -1673,6 +1675,7 @@ MailFunctions.prototype = {
         // refill message text
         this.oo.attachments = [{
             content_type: messageFormat,
+            raw: !editorEnabled,
             content: editorEnabled ? tinyMCE.activeEditor.getContent()
                                    : jQuery('#editor_content').val()
         }];
@@ -1753,7 +1756,7 @@ MailFunctions.prototype = {
                 getStyleTextOfDefaultFont() + '">' +
                 tinyMCE.activeEditor.getContent() + '</body></html>';
         } else {
-            return replaceSpaces(jQuery('#editor_content').val(), true);
+            return jQuery('#editor_content').val();
         }
     },
 
@@ -1794,6 +1797,7 @@ MailFunctions.prototype = {
         this.ooA.content_type = messageFormat;
         // get content
         this.ooA.content = this.getEditorContent();
+        this.ooA.raw = !editorEnabled;
 
         // build the final attachment object
         var tmp_attachObj = [],
@@ -2594,6 +2598,7 @@ function convertContent(content) {
                   from: configGetKey("modules.mail.defaultaddress"),
                   attachments: [{
                       content_type: editorEnabled ? "text/plain" : "text/html",
+                      raw: editorEnabled,
                       content: content
                   }]
               }) + '\r\n--' + boundary + '--'
