@@ -1412,8 +1412,21 @@ ox.uwa.save = function (cont) {
             processData: false,
             data: toStore,
             success: function (data) {
+                // some evil id mapping
+                for (var i=0; i < toStore.length; i++) {
+                    var tmpObj = toStore[i];
+                    // only if new and no error
+                    if (tmpObj.action === "new" && !data[i].error) {
+                        var oldWidget = ox.uwa.get(tmpObj.data.id);
+                        // store old reference, required to update the grid later on
+                        data[i].data.tmp_id = oldWidget.id;
+                        // update cache
+                        oldWidget.id = data[i].data.id;
+                    }
+                    tmpObj = null;
+                }
                 // reset temp cache
-                ox.uwa.toStore = {};
+                ox.uwa.toStore = {}, toStore = null;
                 if (cont) {
                     cont(data);
                 }
