@@ -268,7 +268,7 @@ function getFullAddress(name, address) {
 function ObjectToArray(object) {
     var tmp = [];
     for (var i in object) {
-        tmp.push(object[i]);
+        if (object.hasOwnProperty(i)) tmp.push(object[i]);
     }
     return tmp;
 }
@@ -292,4 +292,4 @@ function isGroupAppointment(participants) {
         }
     }
     return false;
-}
\ No newline at end of file
+}
