@@ -291,7 +291,10 @@ ox.gui.Menu = ox.gui.Container.extend({
             // render both the widget as well as the menuStrip
             if (this.menuStrip) {
                 // copy flag
-                this.menuStrip.requiresValidation = !!(this.requiresValidation || force);
+                this.menuStrip.requiresValidation = !!(
+                    this.menuStrip.requiresValidation ||
+                    this.requiresValidation ||
+                    force);
                 // validate menu strip
                 this.menuStrip.validate();
             }
@@ -373,7 +376,7 @@ ox.gui.Menu = ox.gui.Container.extend({
                 // arrow?
                 if (this.hasChildren()) {
                     div.append(
-                        $("<img/>", { src: ox.gui.themePath + "img/arrows/menu_arrow_down.gif" }).
+                        $("<img/>", { src: ox.gui.themePath + "img/arrows/sort_down.gif" }).
                             addClass("menu-item-arrow")
                     );
                 }
@@ -412,7 +415,7 @@ ox.gui.Menu = ox.gui.Container.extend({
                     if (this.hasChildren()) {
                         node.append(
                              $("<img/>", {
-                                src: ox.gui.themePath + "img/arrows/menu_arrow_down.gif",
+                                src: ox.gui.themePath + "img/arrows/sort_down.gif",
                                 alt: ""
                              })
                             .addClass("menu-item-arrow menu-item-split")
@@ -438,7 +441,7 @@ ox.gui.Menu = ox.gui.Container.extend({
                     // arrow?
                     if (this.hasChildren()) {
                         node.append(
-                            $("<img/>", { src: ox.gui.themePath + "img/arrows/menu_arrow_down.gif", alt: "" }).
+                            $("<img/>", { src: ox.gui.themePath + "img/arrows/sort_down.gif", alt: "" }).
                                 addClass("menu-item-arrow")
                         );
                     }
