@@ -870,46 +870,43 @@ com_openexchange_subscribe.func_button_refresh_subscription_folder = function(mo
         
         // only set if button is available
         if (subscribe && subscribe.options) {
-            // add available subscribe services to button
-            var availableTypes = com_openexchange_subscribe.modules[modulename];
-            if (!isEmpty(availableTypes)) {
-                for (var i in availableTypes) (function(type) {
-                    var def = availableTypes[type];
-                    subscribe.add(new ox.gui.MenuItem({ 
-                            title: noI18n(def.displayName),
-                            id: modulename + "-socialOX-subscribe-" + type,
-                            action: function() {
-                                // switch to properties and tab
-                                triggerEvent("Feature_Subscriptions");
-                                setTimeout(function() {
-                                    // init new object
-                                    com_openexchange_subscribe.tab.addNew({});
-                                    // pre-select the given subscribe service
-                                    if (typeof com_openexchange_subscribe.tab.children[0].children[0].combobox != "undefined") {
-                                        com_openexchange_subscribe.tab.children[0].children[0].combobox.setValue(def.displayName);
-                                    }
-                                });
-                            }, 
-                            icons: ["img/dummy.gif"] 
-                        })
-                    );
-                })(i);
+            var sources = com_openexchange_subscribe.sources;
+            for (var i in sources) {
+                var m = sources[i].module;
+                if (m == modulename) {
+                    // ignore google subscription for default calendar folder
+                    if (m === "calendar" && sources[i].id.match(/.google.calendar$/) &&
+                            String(activefolder) === String(ox.api.config.get('folder.calendar'))) {
+                        continue;
+                    }
+
+                    (function(mySources) { 
+                            subscribe.add(new ox.gui.MenuItem({ 
+                                title: noI18n(mySources.displayName),
+                                id: modulename + "-socialOX-subscribe-" + mySources.id,
+                                action: function() {
+                                    // switch to properties and tab
+                                    triggerEvent("Feature_Subscriptions");
+                                    setTimeout(function() {
+                                        // init new object
+                                        com_openexchange_subscribe.tab.addNew({});
+                                        // pre-select the given subscribe service
+                                        if (typeof com_openexchange_subscribe.tab.children[0].children[0].combobox != "undefined") {
+                                            com_openexchange_subscribe.tab.children[0].children[0].combobox.setValue(mySources.displayName);
+                                        }
+                                    });
+                                }, 
+                                icons: ["img/dummy.gif"] 
+                            }, 50)
+                        );
+                    })(sources[i]);
+                }
             }
         }
         // intitialized
         com_openexchange_subscribe.buttons[modulename] = true;
     }
     
-    // Update available subscriptions based on the current folder
-    if (subscribe && subscribe.options) {
-        var availableTypes = com_openexchange_subscribe.modules[modulename];
-        for (var type in availableTypes || {}) {
-            ox.desktop.getWidget(modulename + "-socialOX-subscribe-" + type)
-                .setVisible(!type.match(/.google.calendar$/) ||
-                    String(activefolder) !==
-                    String(ox.api.config.get('folder.calendar')));
-        }
-    }
 };
 
 function refreshFolder(options) {
@@ -1114,7 +1111,10 @@ tab.init = function() {
     MenuNodes.createSmallButton(menu, "subscribe.subscriptions.add", _("Add"),
         getFullImgSrc("img/menu/add_category.gif"),
         getFullImgSrc("img/menu/add_category_d.gif"),
-        function() { tab.addNew({}); });
+        function() { 
+            tab.addNew({});
+            tab.listModified = true;
+        });
     MenuNodes.createSmallButton(menu, "subscribe.subscriptions.remove", _("Remove"),
         getFullImgSrc("img/menu/remove_category.gif"),
         getFullImgSrc("img/menu/remove_category_d.gif"), confirmDelete);
